@@ -597,6 +597,8 @@ psscan(const char *filename, int scanstyle)
 			if (maxpages > 0) {
 			    doc->pages = (struct page *) PS_calloc(maxpages,
 							   sizeof(struct page));
+                            if (!doc->pages)
+                                maxpages = 0;
                             CHECK_MALLOCED(doc->pages);
 			}
 		}
@@ -1002,14 +1004,14 @@ psscan(const char *filename, int scanstyle)
 	section_len += line_len;
     }
 
+    if (maxpages == 0) {
+	maxpages = 1;
+	doc->pages = (struct page *) PS_calloc(maxpages, sizeof(struct page));
+	CHECK_MALLOCED(doc->pages);
+    }
 
 newpage:
     while (DSCcomment(line) && iscomment(line+2, "Page:")) {
-	if (maxpages == 0) {
-	    maxpages = 1;
-	    doc->pages = (struct page *) PS_calloc(maxpages, sizeof(struct page));
-            CHECK_MALLOCED(doc->pages);
-	}
 	label = ps_gettext(line+length("%%Page:"), &next_char);
 	if (sscanf(next_char, "%u", &thispage) != 1) thispage = 0;
 	if (nextpage == 1) {
@@ -1188,8 +1190,9 @@ continuepage:
 	section_len += line_len;
     } else if (doc->doseps) {
         /* No EOF, make sure endtrailer <= ps_end */
-        if (position > doc->doseps->ps_begin + doc->doseps->ps_length) {
-	    position = doc->doseps->ps_begin + doc->doseps->ps_length;
+        long ps_end = doc->doseps->ps_begin + doc->doseps->ps_length;
+        if (position > ps_end) {
+            position = ps_end;
 	    section_len = position - doc->begintrailer;
 	    line_len = 0;
 	}
